require 'spec_helper'

describe SPImaging::ShowImagesRequest do
  subject do
    SPImaging::ShowImagesRequest.new(['UUID-1', 'UUID-2'])
  end

  it 'downloads the file' do
    server.response = [200, {'content-type' => 'text/plain'}, "test file"]

    response = subject.download
    response.body.should == "test file"
    response.content_type.should == 'text/plain'
    response.content_encoding.should be_nil
  end

  it 'includes the content encoding' do
    server.response = [200, {'content-type' => 'text/plain', 'content-encoding' => 'gzip'}, "test file"]

    response = subject.download
    response.body.should == "test file"
    response.content_type.should == 'text/plain'
    response.content_encoding.should == 'gzip'
  end

  it 'includes the content disposition' do
    server.response = [200, {'content-type' => 'text/plain', 'content-disposition' => 'attachment; filename=test.txt'}, 'test file']
    response = subject.download
    response.content_disposition.should == 'attachment; filename=test.txt'
  end

  # it 'downloads real content' do
  #   real_request = SPImaging::ShowImagesRequest.new(['c49abdea-8402-4dd0-914a-e41f6f9c776a', 'ae3227e5-9575-446b-b657-72d8793de7e7'])
  #   response = real_request.download
  #   response.content_type.should == 'application/pdf'
  #   response.content_encoding.should == 'gzip'
  # end
end
